@@ -1,38 +1,41 @@
-from __future__ import absolute_import, division, print_function, unicode_literals
+from __future__ import absolute_import, division, print_function, \
+    unicode_literals
 import numpy as np
 from sklearn.preprocessing import LabelEncoder
 
 
 def binary_ks_curve(y_true, y_probas):
-    """This function generates the points necessary to calculate the KS Statistic curve.
+    """This function generates the points necessary to calculate the KS
+    Statistic curve.
 
     Args:
         y_true (array-like, shape (n_samples)): True labels of the data.
 
-        y_probas (array-like, shape (n_samples)): Probability predictions of the positive class.
+        y_probas (array-like, shape (n_samples)): Probability predictions of
+            the positive class.
 
     Returns:
-        thresholds (numpy.ndarray): An array containing the X-axis values for plotting the
-            KS Statistic plot.
+        thresholds (numpy.ndarray): An array containing the X-axis values for
+            plotting the KS Statistic plot.
 
-        pct1 (numpy.ndarray): An array containing the Y-axis values for one curve of the
-            KS Statistic plot.
+        pct1 (numpy.ndarray): An array containing the Y-axis values for one
+            curve of the KS Statistic plot.
 
-        pct2 (numpy.ndarray): An array containing the Y-axis values for one curve of the
-            KS Statistic plot.
+        pct2 (numpy.ndarray): An array containing the Y-axis values for one
+            curve of the KS Statistic plot.
 
-        ks_statistic (float): The KS Statistic, or the maximum vertical distance between the
-            two curves.
+        ks_statistic (float): The KS Statistic, or the maximum vertical
+            distance between the two curves.
 
-        max_distance_at (float): The X-axis value at which the maximum vertical distance between
-            the two curves is seen.
+        max_distance_at (float): The X-axis value at which the maximum vertical
+            distance between the two curves is seen.
 
-        classes (np.ndarray, shape (2)): An array containing the labels of the two classes making
-            up `y_true`.
+        classes (np.ndarray, shape (2)): An array containing the labels of the
+            two classes making up `y_true`.
 
     Raises:
-        ValueError: If `y_true` is not composed of 2 classes. The KS Statistic is only relevant in
-            binary classification.
+        ValueError: If `y_true` is not composed of 2 classes. The KS Statistic
+            is only relevant in binary classification.
     """
     y_true, y_probas = np.asarray(y_true), np.asarray(y_probas)
     lb = LabelEncoder()
@@ -96,7 +99,8 @@ def binary_ks_curve(y_true, y_probas):
         pct2 = np.append(pct2, [1.0])
 
     differences = pct1 - pct2
-    ks_statistic, max_distance_at = np.max(differences), thresholds[np.argmax(differences)]
+    ks_statistic, max_distance_at = (np.max(differences),
+                                     thresholds[np.argmax(differences)])
 
     return thresholds, pct1, pct2, ks_statistic, max_distance_at, lb.classes_
 
@@ -141,8 +145,69 @@ def validate_labels(known_classes, passed_labels, argument_name):
     if np.any(passed_labels_absent):
         absent_labels = [str(x) for x in passed_labels[passed_labels_absent]]
 
-        msg = "The following labels were passed into {0}, but were not found in labels: {1}" \
-                .format(argument_name, ", ".join(absent_labels))
+        msg = ("The following labels "
+               "were passed into {0}, "
+               "but were not found in "
+               "labels: {1}").format(argument_name, ", ".join(absent_labels))
         raise ValueError(msg)
 
     return
+
+
+def cumulative_gain_curve(y_true, y_score, pos_label=None):
+    """This function generates the points necessary to plot the Cumulative Gain
+
+    Note: This implementation is restricted to the binary classification task.
+
+    Args:
+        y_true (array-like, shape (n_samples)): True labels of the data.
+
+        y_score (array-like, shape (n_samples)): Target scores, can either be
+            probability estimates of the positive class, confidence values, or
+            non-thresholded measure of decisions (as returned by
+            decision_function on some classifiers).
+
+        pos_label (int or str, default=None): Label considered as positive and
+            others are considered negative
+
+    Returns:
+        percentages (numpy.ndarray): An array containing the X-axis values for
+            plotting the Cumulative Gains chart.
+
+        gains (numpy.ndarray): An array containing the Y-axis values for one
+            curve of the Cumulative Gains chart.
+
+    Raises:
+        ValueError: If `y_true` is not composed of 2 classes. The Cumulative
+            Gain Chart is only relevant in binary classification.
+    """
+    y_true, y_score = np.asarray(y_true), np.asarray(y_score)
+
+    # ensure binary classification if pos_label is not specified
+    classes = np.unique(y_true)
+    if (pos_label is None and
+        not (np.array_equal(classes, [0, 1]) or
+             np.array_equal(classes, [-1, 1]) or
+             np.array_equal(classes, [0]) or
+             np.array_equal(classes, [-1]) or
+             np.array_equal(classes, [1]))):
+        raise ValueError("Data is not binary and pos_label is not specified")
+    elif pos_label is None:
+        pos_label = 1.
+
+    # make y_true a boolean vector
+    y_true = (y_true == pos_label)
+
+    sorted_indices = np.argsort(y_score)[::-1]
+    y_true = y_true[sorted_indices]
+    gains = np.cumsum(y_true)
+
+    percentages = np.arange(start=1, stop=len(y_true) + 1)
+
+    gains = gains / float(np.sum(y_true))
+    percentages = percentages / float(len(y_true))
+
+    gains = np.insert(gains, 0, [0])
+    percentages = np.insert(percentages, 0, [0])
+
+    return percentages, gains
